# Base URL
ACCESS_TOKEN_URL = "https://accounts.tokopedia.com/token"
PLAYGROUND_SAT_BASE_URL = "https://b2b-playground.tokopedia.com/api"

# Path
PING_PATH = "/ping"
INQUIRY_PATH = "/v2/inquiry"
CHECKOUT_PATH = "/v2/order"
CHECK_STATUS_PATH = "/v2/order/{request_id}"
PRODUCT_LIST_PATH = "/v2/product-list"
ACCOUNT_PATH = "/v2/account"

SIGNATURE_HEADER_KEY = "signature"

SDK_NAME = "py_sat"
SDK_VERSION = "v1.0.0"
SDK_LABEL = f"{SDK_NAME}@{SDK_VERSION}"

DATE_TIME_FORMAT = "%a, %d %b %Y %H:%M:%S GMT"



from datetime import datetime
from typing import Optional

from dataclasses_json import dataclass_json, Undefined, DataClassJsonMixin, config
from dataclasses import dataclass

import dateutil.parser
import requests


class BaseResponse(DataClassJsonMixin):
    _raw_response: requests.Response

    def get_raw_response(self) -> requests.Response:
        return self._raw_response

    def with_raw_response(self, raw_response: requests.Response):
        self._raw_response = raw_response
        return self

    def is_success(self):
        return 200 <= self._raw_response.status_code < 300


class BaseRequest(DataClassJsonMixin):
    pass


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclass
class Field:
    name: str
    value: str


def datetime_encoder(input: Optional[datetime]) -> str:
    if input is None:
        return None

    return input.isoformat()


def datetime_decoder(input: Optional[str]) -> Optional[datetime]:
    if input is None:
        return None

    return dateutil.parser.isoparse(input)


datetime_config = config(
    encoder=datetime_encoder,
    decoder=datetime_decoder,
)



from dataclasses_json import dataclass_json, Undefined
from dataclasses import dataclass
from py_sat.models.base import BaseResponse


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclass
class PingResponse(BaseResponse):
    buildhash: str
    sandbox: bool
    status: str
